---
author: Guido Milanese^[Università Cattolica del Sacro Cuore, Dipartimento di Scienze Storiche e Filologiche, via Trieste 17, I-25121 Brescia BS -- email guido.milanese@unicatt.it]
bibliography:
- '/home/guido/Biblio/letant.bib'
- '/home/guido/Biblio/lingcomp.bib'
date: 27^th^ September 2022
lang: en
title: | 
    Verpot manual\
    version 1.0.1
documentclass: article
fontfamily:  libertine
fontfamilyoptions: osf
fontsize: 12pt
papersize: a4
biblio-style: philosophy-modern
biblatexoptions: backend=biber,autocite=plain,scauthors=all
header-includes: 
-  '\usepackage{libertinegc}'
-  '\usepackage[autostyle=once]{csquotes}'
-  '\DeclareFieldFormat[article]{citetitle}{\emph{#1}}'
-  '\DeclareFieldFormat[inproceedings]{citetitle}{\emph{#1}}'
-  '\DeclareFieldFormat[article]{journaltitle}{«{#1}»}'
---

#	What is Verpot

[Verpot]{.smallcaps} is a tool designed to use the Latin core lexicon list of words (hence "CLW") developed by the Liège-Besançon research groups (see @Cauquil:Vocabulaire). The features offered by [Verpot]{.smallcaps} are the following ones:

*  output a range of words in the CLW (e.g. words from 100 to 200 in the frequency order);
*  output all the entries featuring a given part of speech, e.g. all the adverbs, listed in the CLW;
*  find if a single lemma is listed in the CLW;
*  parse a text chosen by user with a lemmatiser and find:

   -  words listed in the CWL
   *  words not listed in the CWL but known to the lemmatiser
   *  words unknown to the lemmatiser

## Role within the Eulalia project
One of the main tasks of the Eulalia project^[European Latin Linguistic Assessment: Erasmus+ Strategic Partnership for Higher Education (2019-2022). See <https://site.unibo.it/eulalia/en>.] is to stanrdardise a core vocabulary of Latin in order to make it possible a European certification of Latin. This tool is designed to help teachers and students use the CLW as effectively as possible.

## License
[Verpot]{.smallcaps} is free software. The chosen license is the MIT license (see <https://opensource.org/licenses/MIT>). The text of the license is available both online (see above) and is distributed with [Verpot]{.smallcaps}. Please notice that "free" means the freedom to use, study, distribute, modify the programme; it is not a synonymous of "gratis (= zero price)" software (unavoidable reference: @Stallman:Free).

# Requirements
[Verpot]{.smallcaps} is a script, not a stand-alone programme, and requires the following programmes (all of them are free software):

*  a **Snobol4** compiler. The reason of choosing this programming language is its great flexibility as a tool for text analysis. The most recent version is dated March 2022 (see <http://www.regressive.org/snobol4/csnobol4/curr/>). On this language, one of the "great classics" of the '70, a good introduction is still @Hockey:Snobol-Humanities. Most recently, see @Milanese:Filologia-letteratura-computer [241-243].
*  the lemmatiser used by [Verpot]{.smallcaps} is **treetagger**: see <https://www.cis.uni-muenchen.de/~schmid/tools/TreeTagger/>
*  the graphical user interface (GUI) is provided by **zenity**, that allows the execution of dialog boxes, information windows, warnings and so on. It is cross platform; simple but effective (<https://wiki.gnome.org/action/show/Projects/Zenity>).

# Linux version
The Linux version is distributed leaving to users the task of installing the required software. Detailed instruction follows.

## Installation: Linux
*  Install **snobol4**. 
   - Read the install file at <http://www.regressive.org/snobol4/csnobol4/curr/INSTALL>
   - Download the most recent version, at the date of writing <http://ftp.regressive.org/snobol4/snobol4-2.3.1.tar.gz>. 
   - make sure to have **m4** installed: if not, all the package managers, e.g. **synaptic** in Debian/Ubuntu distributions, will install **m4** in a few seconds;
   - unzip the package: open a shell and type `tar -xf snobol4-2.3.1.tar.gz`.
   - change directory to `snobol4-2.3.1`.
   * run `./configure`
   * run `make`
   * as superuser run `make install`
   * test the compiler: open a shell and type `snobol4`. The compiler should output a version message and a prompt. Type `end` or hit Control-c to exit.
*  Install tree-tagger. 
   - Follow the detailed instruction provided here: <https://www.cis.uni-muenchen.de/~schmid/tools/TreeTagger/>. The Latin parameter file is <https://www.cis.uni-muenchen.de/~schmid/tools/TreeTagger/data/latin.par.gz>. 
   - To test the lemmatiser, type in a shell: `echo "Filii et filiae amant patrem et matrem" | tree-tagger-latin`. The lemmatiser should output a list of tagged words, as `Filii N:nom filius`.
*  To install **zenity** use your package manager. Make sure that the installed version is recent. Old versions do not offer all the features required by [Verpot]{.smallcaps}. 
*  To install [Verpot]{.smallcaps} unpack the zipped archive **verpot-source** in any directory you can access. Personally I would recommend **/home/<user>/bin**, provided it is listed in your `PATH` (or add this folder to your `PATH`): the result will be a folder labeled **/home/<user>/bin/Verpot**, such as **/home/john/bin/Verpot**. The [Verpot]{.smallcaps} icon can be copied to your desktop and the programme will run from desktop with no need to open a shell; just edit the properties according to the folder you have chosen to host the programme. 

## Usage: Linux
Either (1) call the programme clicking on the [Verpot]{.smallcaps} icon on desktop or (2) open a shell, go to the directory where you have unzipped the package, and type `./corelex.sno`. If it does not work, try `snobol4 corelex.sno` or mark **corelex.sno** as executable (`chmod +x corelex.sno`). The menus should be self-explanatory, but see the images at the end of this manual.

# Windows version
The source file is basically the same, with some necessary changes^[For those who are familiar with Unix/Windows commands: for example **grep** was changed to **findstr**, the syntax of **sort** was changed, and so on.]. I provide two different installation methods.

## Installation: Windows: complete procedure
In this case, the installation follows the same steps necessary for the installation under Linux. Advantage: all the tools installed (**snobol**, **tree-tagger**...) will be available also _outside_ [Verpot]{.smallcaps}. Disadvantage: the procedure requires some time and some attention. Follow the same steps described above about Linux, but before everything else make sure to have a **Perl**  interpreter already installed, necessary to run **tree-tagger** . If you don't, don't panic: the installation for Windows is very simple, a one-click procedure: see e.g. <https://strawberryperl.com/>, click on <https://strawberryperl.com/download/5.32.1.1/strawberry-perl-5.32.1.1-64bit.msi> and wait for the installer to do its work.

## Installation: Windows: quick and dirty
* First, install Perl (see above). This is necessary to run **tree-tagger**.
* Then, copy **verpot-win-install.exe** and **verpot-win-files.exe** to your home directory, for example `c:\Users\john`. You can also run the installer from any other folder, e,g, from your Download directory, but make sure to extract files to your personal directory.
* Now click on **verpot-win-install**. The script will extract all the necessary files to your personal directory, such as `c:\Users\john`. _Make sure of this when prompted by the installation windows_. The installer defaults to unpack the archive in that folder; this is essential because the programmes are hard-coded to work from this folder. If you try to install the programme to another folder, [Verpot]{.smallcaps} the programme will not work.
*  The installation script should install a link icon to your desktop. If not, to add a link with icon to your desktop you can either click on **verpot.bat**, right mouse button, "add link to desktop", or simply copy **verpot.lnk** to the desktop. Change the icon as you prefer.
*  The interpreter (**snobol4**), the tagger and [Verpot]{.smallcaps} itself will be installed in the same directory and its sub-directories. This system is really quick and dirty, does not need any tricky operation and should work immediately. Disadvantage: for example you will not be able to use **tree-tagger** outside that particular folder.

## Usage: Windows
*  Click on the [Verpot]{.smallcaps} icon on desktop and run the programme, or
*  open a shell (command prompt: write `cmd` on the little window where you write commands). This will open a shell windows; type for example `cd c:\Users\john\Verpot`,  and then `verpot.bat`. This will run the programme and call the tagger and **zenity**.

# History
* 2020 (January-June): first draft
* 2021.06.01: programme working, with some problems (hanging on some loops, could not recognize proper nouns)
* 2022.06.01: draft of a Windows version 
* 2022.09.20: Windows version ready, PDF manual, README and `man page` for Linux.
* 2022.09.24: Windows installation file ready

# Problems, bugs, "todo"
*  Windows version: run the programme to any folder chosen by user. The problem is given by the unpredictable permissions in many Windows installations.
*  a Mac version is still a _desideratum_
*  users could contribute to the programme improving the Latin parameter file, i.s. adding unknown words to the words recognised by **tree-tagger**. Instructions on the home page of the tagger.
*  very difficult issue: different orthography for the same word. For example, _CLW_ lists _adolescens_ but not _adulescens_. A good idea would be to add "double entries" to the word list.
*  make [Verpot]{.smallcaps} a more general teaching tool. With some adaptation the tool could be used for any language. Beginning with Greek could be a good idea.

# Contacts
Please write to `guido.milanese@unicatt.it`. Thank you.

![Title window (Linux version)](vp01.png){height=70%}

![Main menu](vp02.png){height=70%}

![Word lists](vp03.png){height=70%}

![Files written after parsing a text](vp04.png){height=50%}

